@@ -38,7 +38,7 @@ class ExcelRenderer:
     ROW_START = 3
     global res
     res = ''
-    def __init__(self, analysis_run, tenantId, excel_data, report_gen_start_time, report_gen_completed_time):
+    def __init__(self, analysis_run, tenantId, additional_props, excel_data, report_gen_start_time, report_gen_completed_time):
         """
         :param analysis_run: AnalysisRun
         """
@@ -48,6 +48,7 @@ class ExcelRenderer:
         self.excel_data = excel_data
         self.report_gen_start_time = report_gen_start_time
         self.report_gen_completed_time = report_gen_completed_time
+        self.additional_props = additional_props
         
         def get_token():
             headers = {"Content-Type" : "application/x-www-form-urlencoded" , "Accept" : "application/json"};
@@ -334,9 +335,26 @@ class ExcelRenderer:
                 chart.x_axis.majorTimeUnit = "days"
 
         ws.add_chart(chart, chart_data['chart-position'])
+        
+        
+    def client_names_ids(self, customer_name):
+        names = ''
+        client_id = ''
+        if customer_name and customer_name is not None:
+            for i in customer_name:
+                for j in i.items():
+                    names+=j[1]['name']
+                    client_id+=j[1]['uniqueId']
+                    names+=', '
+                    client_id+=', '
+            names = names.rstrip(', ')
+            client_id = client_id.rstrip(', ')
+            return names, client_id
+        else:
+            return names, client_id
 
 
-    def generate_summary(self, res, tenantId, report_gen_start_time, report_gen_completed_time):
+    def generate_summary(self, res, tenantId, additional_props, report_gen_start_time, report_gen_completed_time):
         """
         add summary sheet
         """
@@ -350,7 +368,18 @@ class ExcelRenderer:
         ws.column_dimensions['B'].width = 24
         ws.column_dimensions['C'].width = 24
         
+        c_name = ''
+        c_id = ''
+        opsql_params = None
+        if additional_props and additional_props is not None:
+            if 'client_names' in additional_props:
+                client_res = additional_props['client_names']
+                result = self.client_names_ids(client_res)
+                c_name = result[0]
+                c_id = result[1]
 
+            if 'opsql_query' in additional_props:
+                opsql_params = additional_props['opsql_query']
         
         cell = ws['B4']
         cell.value = 'App'
@@ -368,7 +397,8 @@ class ExcelRenderer:
         cell.fill = PatternFill("solid", fgColor="eeeeee")
 
         cell = ws['C5']
-        cell.value = res.json()['tenantInfo']['tenantName']
+        # cell.value = res.json()['tenantInfo']['tenantName']
+        cell.value = c_name
         cell.font = Font(color="000000")
         cell.fill = PatternFill("solid", fgColor="eeeeee")
 
@@ -378,7 +408,8 @@ class ExcelRenderer:
         cell.fill = PatternFill("solid", fgColor="eeeeee")
 
         cell = ws['C6']
-        cell.value = tenantId
+        # cell.value = tenantId
+        cell.value = c_id
         cell.font = Font(color="000000")
         cell.fill = PatternFill("solid", fgColor="eeeeee")
 
@@ -415,6 +446,26 @@ class ExcelRenderer:
         cell.font = Font(color="000000")
         cell.fill = PatternFill("solid", fgColor="eeeeee")
 
+        header_idx = 9
+        value_idx = 9
+        if opsql_params is not None:
+
+            for key in opsql_params.keys():
+                header_idx += 1
+                value_idx += 1
+                display_name = self.get_display_name(key)
+                display_value = self.get_display_value(opsql_params[key])
+
+                cell = ws[f'B{header_idx}']
+                cell.value = display_name
+                cell.font = Font(color="00598B")
+                cell.fill = PatternFill("solid", fgColor="eeeeee")
+
+                cell = ws[f'C{value_idx}']
+                cell.value = display_value
+                cell.font = Font(color="000000")
+                cell.fill = PatternFill("solid", fgColor="eeeeee")
+
         # cell = ws['B10']
         # cell.value = 'Analysis Parameters'
         # cell.font = Font(color="00598B")
@@ -445,6 +496,28 @@ class ExcelRenderer:
         # cell.font = Font(color="000000")
         # cell.fill = PatternFill("solid", fgColor="eeeeee")
 
+    def get_display_name(self, key):
+        if key == 'filterCriteria':
+            return 'Query'
+        if key == 'fields':
+            return 'Attributes'
+        if key == 'groupBy':
+            return 'Group By'
+        if key == 'soryBy':
+            return 'Sort By'
+        if key == 'sortByOrder':
+            return 'Sort By Order'
+        return key
+
+    def get_display_value(self, value):
+        if value is None and len(value) <= 0:
+            return '-'
+        else:
+            if isinstance(value, list):
+                all_values = ', '.join([val for val in value])
+                return all_values
+        return value
+
     def add_header(self, ws, sheet_data):
         """
         add header to the sheet
@@ -496,7 +569,8 @@ class ExcelRenderer:
         tenantId = self.tenantId
         report_gen_start_time = self.report_gen_start_time
         report_gen_completed_time = self.report_gen_completed_time
-        self.generate_summary(res, tenantId, report_gen_start_time, report_gen_completed_time)
+        additional_props = self.additional_props
+        self.generate_summary(res, tenantId, additional_props, report_gen_start_time, report_gen_completed_time)
         # run_data = self.analysis_run
         run_data = self.excel_data
         for sheet in run_data['sheets']:
