@@ -33,6 +33,8 @@ APP_ID = os.getenv('APP_ID')
 API_TIME_STACKS = int(os.getenv('API_TIME_STACKS', 5))
 
 from .renderer.excel import ExcelRenderer
+from .renderer.pdf import PDF
+
 storage_name = os.getenv('STORAGE_NAME')
 
 global ACCESS_KEY_ID, SECRET_ACCESS_KEY, REGION_NAME, BUCKET_NAME, ACCESS_HEADER, TOKEN_RETRIES
@@ -344,57 +346,74 @@ def upload_to_storage(content, location):
             pass
     else:
         logger.info("No storages are found")
-        
+
 
 def generate_pdf(analysis_run):
     logger.info('Entered into pdf generation process')
-    url = os.getenv("PDF_SERVICE")
-    # analysis_run = json.dumps(analysis_run)
-    data = {
-        'domain': BASE_API_URL,
-        'report': PLATFORM_ROUTE,
-        'run': analysis_run,
-        'route': '/full-view',
-        'token': get_token(),
-        'app_id': APP_ID,
-        'size': 'A4',
-        'storage': storage_name
-    }
+    try:
+        url = os.getenv("PDF_SERVICE")
+        current_date = datetime.now()
+        file_name = APP_ID.lower() + '-' + analysis_run[:8] + '-' + current_date.strftime("%Y-%m-%d-%H-%M-%S") + '.pdf'
+        report_path = ''
+        if storage_name == 's3':
+            report_path = PLATFORM_ROUTE
+        elif storage_name == 'ceph':
+            report_path = APP_ID.lower()
+        data = {
+            'domain': BASE_API_URL,
+            'report': PLATFORM_ROUTE,
+            'run': analysis_run,
+            'route': '/full-view',
+            'token': get_token(),
+            'app_id': APP_ID,
+            'size': 'A4',
+            'storage': storage_name,
+            'file_name': file_name
+        }
+        pdf = PDF(analysis_run, url, file_name, report_path, data)
+        gen_retry = 1
+        while gen_retry <= 2:
+            logging.info(f'{pdf.analysis_run} :: pdf generation trying {gen_retry} time..')
+            gen_retry += 1
+            response = pdf.generate()
+            if response == 504:
+                file_path = pdf.report_path + '/' + pdf.analysis_run + '/pdf/' + pdf.file_name
+                storage_retry = 1
+                file_found = False
+                while storage_retry <= API_RETRY:
+                    logging.info(f'{pdf.analysis_run} checking the file is existing in storage or not {storage_retry} time..')
+                    file_found = is_file_in_storage(file_path)
+                    if file_found == True:
+                        logging.info(f'{pdf.analysis_run} the pdf file is found in storage')
+                        return file_path
+                    else:
+                        time.sleep(storage_retry * 30)
+                        storage_retry += 1
+                        logging.info(f'{pdf.analysis_run} pdf not found in storage trying for {storage_retry} time..')
+                        continue
+            else:
+                return response
+        raise Exception(f'Generate_pdf:: pdf generation failed after max tries ({API_RETRY}), for run ::: {pdf.analysis_run}')
+    except Exception as e:
+        traceback.print_exc()
+        raise Exception(f'Generate_pdf:: Exec - pdf generation failed after max tries({API_RETRY}), for run ::: {analysis_run}')
 
-    api_proce_before_time = time.time()
-    res = {}
-    retry = 1
-    while retry <= 3:
-        try:
-            resp = requests.post(url, data=data)
-            if not resp.ok:
-                logging.info(f'{analysis_run} pdf generation failed.. retrying.. {retry} ')
-                time.sleep(retry * 2)
-                retry+=1
-                continue
-            if resp and resp is not None:
-                res = resp.json()
-                api_proce_after_time = time.time()
-                api_proce_diff = diff_sec(api_proce_before_time, api_proce_after_time)
-                if api_proce_diff > API_TIME_STACKS:
-                    logging.info('%s , pdf response is took %d (greater than %d) seconds', analysis_run, api_proce_diff, API_TIME_STACKS)
-                if 'Key' in res:
-                    logger.info('pdf response is: %s', res['Key'])
-                    return res['Key']
-                else:
-                    logging.info(f'key not found, pdf generation failed, returning empty value for runid ::: {analysis_run}')
-                    raise Exception(f'key not found, pdf generation failed for run ::: {analysis_run}')
-        except requests.exceptions.ConnectionError:
-            time.sleep(retry * 2)
-            retry+=1
-            continue
-        except Exception as e:
-            raise Exception(f'pdf generation failed for run ::: {analysis_run}, Exception is : {e}')
-
-    logging.info(f'pdf generationg failed after max tries, returning empty value for runid ::: {analysis_run}')
-    raise Exception(f'pdf generation failed after max tries, for run ::: {analysis_run}')
-        
 
+def is_file_in_storage(file_path: str):
+    try:
+        if storage_name == 's3':
+            s3 = get_s3_client()
+            res_object = s3.get_object(Bucket=BUCKET_NAME,Key=file_path)
+            return True
+        elif storage_name == 'ceph':
+            s3 = get_ceph_resource()
+            data = BytesIO()
+            res_object = s3.Bucket(BUCKET_NAME).download_fileobj(Fileobj=data,Key=file_path)
+            return True
+        else:
+            return False
+    except Exception as e:
+        return False
 
 
 def generate_excel(analysis_run, orgId, client_name, excel_data, report_gen_start_time, report_gen_completed_time, file_name=None):
@@ -468,36 +487,52 @@ def update_results_url(gen_start_time, analysisRunId, tenantId, json_result_url=
 
 #Upload excel file to s3
 def upload_excel_s3(local_file, bucket, s3_file):
+    retry = 1
     s3 = get_s3_client()
-    try:
-        s3.upload_file(local_file, bucket, s3_file)
-        url = f'https://{bucket}.s3.{REGION_NAME}.amazonaws.com/{s3_file}'
-        logger.info('Upload successful, result url is %s', url)
+    while retry <= API_RETRY:
+        try:
+            s3.upload_file(local_file, bucket, s3_file)
+            url = f'https://{bucket}.s3.{REGION_NAME}.amazonaws.com/{s3_file}'
+            logger.info('Upload successful, result url is %s', url)
         
-        delete_excel_file(local_file)
-        return s3_file
-    except FileNotFoundError:
-        logger.info('File was not found')
-        return False
-    except NoCredentialsError:
-        logger.info('Invalid credentials')
-        return False
+            delete_excel_file(local_file)
+            return s3_file
+        except FileNotFoundError:
+            logger.info('File was not found')
+            return False
+        except NoCredentialsError:
+            logger.info('Invalid credentials')
+            return False
+        except Exception as e:
+            time.sleep(retry * 2)
+            retry+=1
+            if retry > API_RETRY:
+                raise e
+            continue
 
 
 #Upload excel file to ceph
 def upload_excel_ceph(local_file, bucket, s3_file):
-    try:
-        s3 = get_ceph_resource()
-        s3.Bucket(BUCKET_NAME).upload_file(Filename = local_file, Key = s3_file)
-        logger.info('Upload successful')
-        delete_excel_file(local_file)
-        return s3_file
-    except FileNotFoundError:
-        logger.info('File was not found')
-        return False
-    except NoCredentialsError:
-        logger.info('Invalid credentials')
-        return False
+    retry = 1
+    s3 = get_ceph_resource()
+    while retry <= API_RETRY:
+        try:
+            s3.Bucket(BUCKET_NAME).upload_file(Filename = local_file, Key = s3_file)
+            logger.info('Upload successful')
+            delete_excel_file(local_file)
+            return s3_file
+        except FileNotFoundError:
+            logger.info('File was not found')
+            return False
+        except NoCredentialsError:
+            logger.info('Invalid credentials')
+            return False
+        except Exception as e:
+            time.sleep(retry * 2)
+            retry+=1
+            if retry > API_RETRY:
+                raise e
+            continue
 
 
 #Delete excel_file from local path
@@ -513,7 +548,7 @@ def delete_excel_file(source_path):
 def generate_excel_file(run_id, orgId, client_name, report_gen_start_time, report_gen_completed_time):
     logger.info('Entered into excel generation process')
     excel_data=get_result_by_run(run_id, 'excel-data', {})
-    reportname = f"{APP_ID.lower()}" + '-' + datetime.now().strftime('%Y-%m-%d-%I-%M-%S') + '.xlsx'
+    reportname = f"{APP_ID.lower()}-{run_id[:8]}" + '-' + datetime.now().strftime('%Y-%m-%d-%I-%M-%S') + '.xlsx'
     filepath = './' + reportname
     generate_excel(run_id, orgId, client_name, excel_data, report_gen_start_time, report_gen_completed_time, filepath)
     # excel_file_location = f'{PLATFORM_ROUTE}/{run_id}/xls/' + reportname
@@ -721,7 +756,9 @@ def get_tenant_list(org_id, level, tenant_list):
 def prepare_tenant_list(form, parameters, all_clients=False):
     tenant_id_list = []
     if parameters is not None and len(parameters) > 0:
-        if 'client' in parameters and parameters['client'] is not None:
+        if 'allClients' in parameters and (parameters['allClients'] == True or parameters['allClients'] == 'true'):
+            tenant_id_list = fetch_all_clients(form.get_tenant_id(), form.get_tenant_context(), all_clients)
+        elif 'client' in parameters and parameters['client'] is not None:
             clients = parameters['client']
             if clients == 'All Clients' or clients == 'All Client':
                 tenant_id_list = fetch_all_clients(form.get_tenant_id(), form.get_tenant_context(), all_clients)
@@ -784,13 +821,18 @@ def get_app_logo(id, context, parameters):
         return get_logo_path_url(id)
     elif context == 'partner':
         if parameters is not None and len(parameters) > 0:
-            if 'client' in parameters and parameters['client'] is not None:
+            if 'allClients' in parameters and (parameters['allClients'] == True or parameters['allClients'] == 'true'):
+                return get_logo_path_url(id)
+            elif 'client' in parameters and parameters['client'] is not None:
                 clients = parameters['client']
-                if len(clients) == 1:
-                    #read client and return path
-                    return get_logo_path_url(clients)
-                elif (clients == 'All Clients' or clients == 'All Client') or len(clients) > 1:
-                    return get_logo_path_url(id)
+                if isinstance(clients, list):
+                    if len(clients) == 1:
+                        for cid in clients:
+                            return get_logo_path_url(cid)
+                    else:
+                        return get_logo_path_url(id)
+                else:
+                    return get_logo_path_url(clients) 
     return get_logo_path_url(id)
 
 
